.. Gnarl documentation master file, created by
   sphinx-quickstart on Sun Jun 28 20:28:16 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Gnarl documentation
===================

Contents:

.. toctree::
   :maxdepth: 2

   quickstart
   apiref


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

